summaryrefslogtreecommitdiff
path: root/noncore/settings/packagemanager
authordrw <drw>2004-12-21 20:14:18 (UTC)
committer drw <drw>2004-12-21 20:14:18 (UTC)
commit1eaf5e3e1f523e5db31d9d9299169b2e278a4568 (patch) (side-by-side diff)
treedc825b52f075d786f65f845ce2179f732da5c45c /noncore/settings/packagemanager
parent2e21be2e93866511f55e2a200514b3ce15b14791 (diff)
downloadopie-1eaf5e3e1f523e5db31d9d9299169b2e278a4568.zip
opie-1eaf5e3e1f523e5db31d9d9299169b2e278a4568.tar.gz
opie-1eaf5e3e1f523e5db31d9d9299169b2e278a4568.tar.bz2
Hide Retrive File List button once list is retrieved in Package Info dialog, bump version up to 0.6.0, update ChangeLog/Todo/etc.
Diffstat (limited to 'noncore/settings/packagemanager') (more/less context) (ignore whitespace changes)
-rw-r--r--noncore/settings/packagemanager/ChangeLog8
-rw-r--r--noncore/settings/packagemanager/README2
-rw-r--r--noncore/settings/packagemanager/TODO18
-rw-r--r--noncore/settings/packagemanager/opie-packagemanager.control2
-rw-r--r--noncore/settings/packagemanager/packageinfodlg.cpp27
-rw-r--r--noncore/settings/packagemanager/packageinfodlg.h49
6 files changed, 57 insertions, 49 deletions
diff --git a/noncore/settings/packagemanager/ChangeLog b/noncore/settings/packagemanager/ChangeLog
index 7799136..c776ce5 100644
--- a/noncore/settings/packagemanager/ChangeLog
+++ b/noncore/settings/packagemanager/ChangeLog
@@ -1,3 +1,11 @@
+2004-12-21 Dan Williams <drw@handhelds.org>
+
+ * Released version 0.6.0
+ * Added support for Ipkg 'src/gz' feeds
+ * Improve server and destination tabs UI's in configuration dialog
+ * Fix app linking to link all dependent packages as well as selected packages
+ * Hide 'Retrive File List' button once list is retrieved in Package Info dialog
+
2004-11-18 Dan Williams <drw@handhelds.org>
* Released version 0.5.0
diff --git a/noncore/settings/packagemanager/README b/noncore/settings/packagemanager/README
index c34a6af..ff6d113 100644
--- a/noncore/settings/packagemanager/README
+++ b/noncore/settings/packagemanager/README
@@ -2,7 +2,7 @@
/*
/* Opie - Package Manager
/* ========================
-/* Version 0.5.0
+/* Version 0.6.0
/*
/* A package management client for Opie
/*
diff --git a/noncore/settings/packagemanager/TODO b/noncore/settings/packagemanager/TODO
index 265beda..744ad95 100644
--- a/noncore/settings/packagemanager/TODO
+++ b/noncore/settings/packagemanager/TODO
@@ -2,24 +2,16 @@
/*
/* Opie - Package Manager
/* ========================
-/* Version 0.5.0
+/* Version 0.6.0
/*
/* A package management client for Opie
/*
/************************************************************************
-----------------------------------------------
- To-do for Opie-PackageManager - November, 2004
+ To-do for Opie-PackageManager - December, 2004
-----------------------------------------------
-======================
-= Current release =
-======================
-
-1. Re-work package download dialog
-
-======================
-= Future releases =
-======================
-
-1. Re-work server and destination tabs in configuration dialog \ No newline at end of file
+1. Move ipkg-link code from InstallDlg to OIpkg
+2. Code ipkg-link logic directly in OIpkg
+3. Re-work package download dialog
diff --git a/noncore/settings/packagemanager/opie-packagemanager.control b/noncore/settings/packagemanager/opie-packagemanager.control
index aacd0ca..cdf419c 100644
--- a/noncore/settings/packagemanager/opie-packagemanager.control
+++ b/noncore/settings/packagemanager/opie-packagemanager.control
@@ -7,4 +7,4 @@ Replaces: packagemanager
Architecture: arm
Maintainer: Dan Williams (drw@handhelds.org)
Description: Opie package management client
-Version: 0.5.0$EXTRAVERSION
+Version: 0.6.0$EXTRAVERSION
diff --git a/noncore/settings/packagemanager/packageinfodlg.cpp b/noncore/settings/packagemanager/packageinfodlg.cpp
index c5924fd..5f72a67 100644
--- a/noncore/settings/packagemanager/packageinfodlg.cpp
+++ b/noncore/settings/packagemanager/packageinfodlg.cpp
@@ -40,10 +40,11 @@ _;:, .> :=|. This file is free software; you can
#include <qwhatsthis.h>
PackageInfoDlg::PackageInfoDlg( QWidget *parent, OPackageManager *pm, const QString &package )
- : QWidget( 0x0 )
+ : QWidget( 0l )
, m_packman( pm )
, m_information( this )
, m_files( this )
+ , m_retrieveFiles( 0l )
{
// Initialize UI
if ( parent )
@@ -88,18 +89,21 @@ PackageInfoDlg::PackageInfoDlg( QWidget *parent, OPackageManager *pm, const QStr
m_files.setReadOnly( true );
filesLayout->addWidget( &m_files );
- QPushButton *btn = new QPushButton( Resource::loadPixmap( "packagemanager/apply" ),
+ // If file list is already cached, display
+ if ( !m_package->files().isNull() )
+ m_files.setText( m_package->files() );
+ else
+ {
+ m_retrieveFiles = new QPushButton( Resource::loadPixmap( "packagemanager/apply" ),
tr( "Retrieve file list" ), filesWidget );
- QWhatsThis::add( btn, tr( "Tap here to retrieve list of files contained in this package." ) );
- filesLayout->addWidget( btn );
- connect( btn, SIGNAL(clicked()), this, SLOT(slotBtnFileScan()) );
- tabWidget->addTab( filesWidget, "binary", tr( "File list" ) );
+ QWhatsThis::add( m_retrieveFiles, tr( "Tap here to retrieve list of files contained in this package." ) );
+ filesLayout->addWidget( m_retrieveFiles );
+ connect( m_retrieveFiles, SIGNAL(clicked()), this, SLOT(slotBtnFileScan()) );
+ }
+ tabWidget->addTab( filesWidget, "binary", tr( "File list" ) );
tabWidget->setCurrentTab( tr( "Information" ) );
- // If file list is already cached, display
- if ( !m_package->files().isNull() )
- m_files.setText( m_package->files() );
}
else
m_files.hide();
@@ -115,7 +119,7 @@ PackageInfoDlg::~PackageInfoDlg()
m_package->setInformation( m_information.text() );
// Cache package file list
- if ( !m_files.text().isNull() )
+ if ( !m_files.text().isEmpty() )
m_package->setFiles( m_files.text() );
}
@@ -125,6 +129,9 @@ void PackageInfoDlg::slotBtnFileScan()
QStringList list( m_package->name() );
m_packman->executeCommand( OPackage::Files, list, QString::null, this, SLOT(slotFiles(char*)), true );
+
+ if ( m_retrieveFiles )
+ m_retrieveFiles->hide();
}
void PackageInfoDlg::slotInfo( char *info )
diff --git a/noncore/settings/packagemanager/packageinfodlg.h b/noncore/settings/packagemanager/packageinfodlg.h
index ec031e1..d1830de 100644
--- a/noncore/settings/packagemanager/packageinfodlg.h
+++ b/noncore/settings/packagemanager/packageinfodlg.h
@@ -1,27 +1,27 @@
/*
-                This file is part of the OPIE Project
+ This file is part of the OPIE Project
=. Copyright (c) 2003 Dan Williams <drw@handhelds.org>
-             .=l.
-           .>+-=
- _;:,     .>    :=|. This file is free software; you can
-.> <`_,   >  .   <= redistribute it and/or modify it under
-:`=1 )Y*s>-.--   : the terms of the GNU General Public
-.="- .-=="i,     .._ License as published by the Free Software
- - .   .-<_>     .<> Foundation; either version 2 of the License,
-     ._= =}       : or (at your option) any later version.
-    .%`+i>       _;_.
-    .i_,=:_.      -<s. This file is distributed in the hope that
-     +  .  -:.       = it will be useful, but WITHOUT ANY WARRANTY;
-    : ..    .:,     . . . without even the implied warranty of
-    =_        +     =;=|` MERCHANTABILITY or FITNESS FOR A
-  _.=:.       :    :=>`: PARTICULAR PURPOSE. See the GNU General
-..}^=.=       =       ; Public License for more details.
-++=   -.     .`     .:
- :     =  ...= . :.=- You should have received a copy of the GNU
- -.   .:....=;==+<; General Public License along with this file;
-  -_. . .   )=.  = see the file COPYING. If not, write to the
-    --        :-=` Free Software Foundation, Inc.,
+ .=l.
+ .>+-=
+_;:, .> :=|. This file is free software; you can
+.> <`_, > . <= redistribute it and/or modify it under
+:`=1 )Y*s>-.-- : the terms of the GNU General Public
+.="- .-=="i, .._ License as published by the Free Software
+- . .-<_> .<> Foundation; either version 2 of the License,
+ ._= =} : or (at your option) any later version.
+ .%`+i> _;_.
+ .i_,=:_. -<s. This file is distributed in the hope that
+ + . -:. = it will be useful, but WITHOUT ANY WARRANTY;
+ : .. .:, . . . without even the implied warranty of
+ =_ + =;=|` MERCHANTABILITY or FITNESS FOR A
+ _.=:. : :=>`: PARTICULAR PURPOSE. See the GNU General
+..}^=.= = ; Public License for more details.
+++= -. .` .:
+: = ...= . :.=- You should have received a copy of the GNU
+-. .:....=;==+<; General Public License along with this file;
+ -_. . . )=. = see the file COPYING. If not, write to the
+ -- :-=` Free Software Foundation, Inc.,
59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.
@@ -45,7 +45,7 @@ class PackageInfoDlg : public QWidget
Q_OBJECT
public:
- PackageInfoDlg( QWidget *parent = 0x0, OPackageManager *pm = 0x0, const QString &package = QString::null );
+ PackageInfoDlg( QWidget *parent = 0l, OPackageManager *pm = 0l, const QString &package = QString::null );
~PackageInfoDlg();
private:
@@ -53,8 +53,9 @@ private:
OPackage *m_package; // Pointer to package to display information for
// UI controls
- QMultiLineEdit m_information; // Multi-line edit to display package information
- QMultiLineEdit m_files; // Multi-line edit to display package file list
+ QMultiLineEdit m_information; // Multi-line edit to display package information
+ QMultiLineEdit m_files; // Multi-line edit to display package file list
+ QPushButton *m_retrieveFiles; // Push button to retrieve file list
private slots:
void slotBtnFileScan();